# boaviztapi-sdk
<p>🎯 Retrieving the impacts of digital elements.</p>
<p>This is a quick demo, to see full documentation <a href=\"https://doc.api.boavizta.org\">click here</a></p>
<h2>Features</h2>
<p>Bellow a list of all available features.</p>
<h3>👄 Verbose</h3>
<p>Verbose is an HTTP parameter. If set at true :</p>
<ul>
<li>Shows the impacts of each component</li>
<li>Shows the value used for each attribute</li>
</ul>
<p><em>\"attribute\": {\"value\": \"value\", \"unit\": \"unit\", \"status\": \"Status\", \"source\": \"Source\", \"min\":\"min\", \"max\":\"max\", \"significant_figures\":\"significant_figures\"}</em></p>
<h3>🔨 Embedded</h3>
<ul>
<li>Embedded impacts are the impacts occurring during raw material extraction, manufacture, distribution and end of life</li>
<li>When end of life is not taken into account, we specified it in the <code>warnings</code></li>
</ul>
<h3>🔌  Usage</h3>
<p>Usage impacts are assessed by multiplying :</p>
<ul>
<li>
<p>a <strong>duration</strong></p>
</li>
<li>
<p>an <strong>impact factor</strong> </p>
</li>
<li>
<p>an <strong>electrical consumption</strong> </p>
</li>
</ul>
<h4>⏲ Duration</h4>
<p>Usage impacts can be given as a router parameter, in hours.</p>
<p>If no duration is given, <strong>the impact is assess for the all life duration of the asset</strong>.</p>
<h4>✖️ Impact factors</h4>
<ul>
<li>Impact factors can be given : <em>\"usage\":{\"elec_factors\":{[criteria]: 0.38}}</em></li>
<li>
<p>Impact factors can be retrieved from : <em>\"usage\":{\"usage_location\": \"FRA\"}</em>. </p>
</li>
<li>
<p>See the list of locations : <a href=\"/v1/utils/country_code\">/v1/utils/country_code</a>*</p>
</li>
</ul>
<h4>⚡ Electrical consumption</h4>
<h5>⏺️ Given</h5>
<ul>
<li>Electrical consumption can be given for one hour (average) <em>\"usage\":{\"avg_power\": 1}</em>.</li>
</ul>
<h5>📈 Modeled</h5>
<ul>
<li>Electrical consumption can be retrieved from consumption profile using <em>usage:{time_workload: 50}</em>.</li>
</ul>
<h5>📋 Archetype</h5>
<ul>
<li>In some cases, default electrical consumption can be taken from the archetype</li>
</ul>
<h3>🔃 Auto-complete &amp; 📋 Archetype</h3>
<p>The API will complete the missing attributes in a request with a completion function or with values
taken from the <code>archetype</code> specified in the route parameter.</p>
<h3>⏬ Allocation</h3>
<ul>
<li>Usage impacts are assessed on the duration given in route parameter</li>
<li>Embedded impacts are allocated linearly on the duration given in parameter
<code>embedded_impact = impact * (duration/life_duration)</code></li>
</ul>
<p>If no duration is given, the life_duration (<code>`hours_life_time</code>) of the asset is used.</p>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.2.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import boaviztapi_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import boaviztapi_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import boaviztapi_sdk
from boaviztapi_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = boaviztapi_sdk.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with boaviztapi_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = boaviztapi_sdk.CloudApi(api_client)
    provider = 'aws' # str |  (optional) (default to 'aws')
    instance_type = 'a1.4xlarge' # str |  (optional) (default to 'a1.4xlarge')

    try:
        # Get Archetype Config
        api_response = api_instance.get_archetype_config_v1_cloud_instance_instance_config_get(provider=provider, instance_type=instance_type)
        print("The response of CloudApi->get_archetype_config_v1_cloud_instance_instance_config_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CloudApi->get_archetype_config_v1_cloud_instance_instance_config_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CloudApi* | [**get_archetype_config_v1_cloud_instance_instance_config_get**](docs/CloudApi.md#get_archetype_config_v1_cloud_instance_instance_config_get) | **GET** /v1/cloud/instance/instance_config | Get Archetype Config
*CloudApi* | [**instance_cloud_impact_v1_cloud_instance_get**](docs/CloudApi.md#instance_cloud_impact_v1_cloud_instance_get) | **GET** /v1/cloud/instance | Instance Cloud Impact
*CloudApi* | [**instance_cloud_impact_v1_cloud_instance_post**](docs/CloudApi.md#instance_cloud_impact_v1_cloud_instance_post) | **POST** /v1/cloud/instance | Instance Cloud Impact
*CloudApi* | [**server_get_all_archetype_name_v1_cloud_instance_all_instances_get**](docs/CloudApi.md#server_get_all_archetype_name_v1_cloud_instance_all_instances_get) | **GET** /v1/cloud/instance/all_instances | Server Get All Archetype Name
*CloudApi* | [**server_get_all_provider_name_v1_cloud_instance_all_providers_get**](docs/CloudApi.md#server_get_all_provider_name_v1_cloud_instance_all_providers_get) | **GET** /v1/cloud/instance/all_providers | Server Get All Provider Name
*ComponentApi* | [**case_all_archetype_name_v1_component_case_archetype_get**](docs/ComponentApi.md#case_all_archetype_name_v1_component_case_archetype_get) | **GET** /v1/component/case/archetype | Case All Archetype Name
*ComponentApi* | [**case_archetype_config_v1_component_case_archetype_config_get**](docs/ComponentApi.md#case_archetype_config_v1_component_case_archetype_config_get) | **GET** /v1/component/case/archetype_config | Case Archetype Config
*ComponentApi* | [**case_impact_bottom_up_v1_component_case_get**](docs/ComponentApi.md#case_impact_bottom_up_v1_component_case_get) | **GET** /v1/component/case | Case Impact Bottom Up
*ComponentApi* | [**case_impact_bottom_up_v1_component_case_post**](docs/ComponentApi.md#case_impact_bottom_up_v1_component_case_post) | **POST** /v1/component/case | Case Impact Bottom Up
*ComponentApi* | [**cpu_all_archetype_name_v1_component_all_get**](docs/ComponentApi.md#cpu_all_archetype_name_v1_component_all_get) | **GET** /v1/component/all | Cpu All Archetype Name
*ComponentApi* | [**cpu_all_archetype_name_v1_component_cpu_archetype_get**](docs/ComponentApi.md#cpu_all_archetype_name_v1_component_cpu_archetype_get) | **GET** /v1/component/cpu/archetype | Cpu All Archetype Name
*ComponentApi* | [**cpu_archetype_config_v1_component_cpu_archetype_config_get**](docs/ComponentApi.md#cpu_archetype_config_v1_component_cpu_archetype_config_get) | **GET** /v1/component/cpu/archetype_config | Cpu Archetype Config
*ComponentApi* | [**cpu_impact_bottom_up_v1_component_cpu_get**](docs/ComponentApi.md#cpu_impact_bottom_up_v1_component_cpu_get) | **GET** /v1/component/cpu | Cpu Impact Bottom Up
*ComponentApi* | [**cpu_impact_bottom_up_v1_component_cpu_post**](docs/ComponentApi.md#cpu_impact_bottom_up_v1_component_cpu_post) | **POST** /v1/component/cpu | Cpu Impact Bottom Up
*ComponentApi* | [**disk_impact_bottom_up_v1_component_hdd_get**](docs/ComponentApi.md#disk_impact_bottom_up_v1_component_hdd_get) | **GET** /v1/component/hdd | Disk Impact Bottom Up
*ComponentApi* | [**disk_impact_bottom_up_v1_component_hdd_post**](docs/ComponentApi.md#disk_impact_bottom_up_v1_component_hdd_post) | **POST** /v1/component/hdd | Disk Impact Bottom Up
*ComponentApi* | [**disk_impact_bottom_up_v1_component_ssd_get**](docs/ComponentApi.md#disk_impact_bottom_up_v1_component_ssd_get) | **GET** /v1/component/ssd | Disk Impact Bottom Up
*ComponentApi* | [**disk_impact_bottom_up_v1_component_ssd_post**](docs/ComponentApi.md#disk_impact_bottom_up_v1_component_ssd_post) | **POST** /v1/component/ssd | Disk Impact Bottom Up
*ComponentApi* | [**hdd_all_archetype_name_v1_component_hdd_archetype_get**](docs/ComponentApi.md#hdd_all_archetype_name_v1_component_hdd_archetype_get) | **GET** /v1/component/hdd/archetype | Hdd All Archetype Name
*ComponentApi* | [**hdd_archetype_config_v1_component_hdd_archetype_config_get**](docs/ComponentApi.md#hdd_archetype_config_v1_component_hdd_archetype_config_get) | **GET** /v1/component/hdd/archetype_config | Hdd Archetype Config
*ComponentApi* | [**motherboard_all_archetype_name_v1_component_motherboard_archetype_get**](docs/ComponentApi.md#motherboard_all_archetype_name_v1_component_motherboard_archetype_get) | **GET** /v1/component/motherboard/archetype | Motherboard All Archetype Name
*ComponentApi* | [**motherboard_archetype_config_v1_component_motherboard_archetype_config_get**](docs/ComponentApi.md#motherboard_archetype_config_v1_component_motherboard_archetype_config_get) | **GET** /v1/component/motherboard/archetype_config | Motherboard Archetype Config
*ComponentApi* | [**motherboard_impact_bottom_up_v1_component_motherboard_get**](docs/ComponentApi.md#motherboard_impact_bottom_up_v1_component_motherboard_get) | **GET** /v1/component/motherboard | Motherboard Impact Bottom Up
*ComponentApi* | [**motherboard_impact_bottom_up_v1_component_motherboard_post**](docs/ComponentApi.md#motherboard_impact_bottom_up_v1_component_motherboard_post) | **POST** /v1/component/motherboard | Motherboard Impact Bottom Up
*ComponentApi* | [**power_supply_all_archetype_name_v1_component_power_supply_archetype_get**](docs/ComponentApi.md#power_supply_all_archetype_name_v1_component_power_supply_archetype_get) | **GET** /v1/component/power_supply/archetype | Power Supply All Archetype Name
*ComponentApi* | [**power_supply_archetype_config_v1_component_power_supply_archetype_config_get**](docs/ComponentApi.md#power_supply_archetype_config_v1_component_power_supply_archetype_config_get) | **GET** /v1/component/power_supply/archetype_config | Power Supply Archetype Config
*ComponentApi* | [**power_supply_impact_bottom_up_v1_component_power_supply_get**](docs/ComponentApi.md#power_supply_impact_bottom_up_v1_component_power_supply_get) | **GET** /v1/component/power_supply | Power Supply Impact Bottom Up
*ComponentApi* | [**power_supply_impact_bottom_up_v1_component_power_supply_post**](docs/ComponentApi.md#power_supply_impact_bottom_up_v1_component_power_supply_post) | **POST** /v1/component/power_supply | Power Supply Impact Bottom Up
*ComponentApi* | [**ram_all_archetype_name_v1_component_ram_archetype_get**](docs/ComponentApi.md#ram_all_archetype_name_v1_component_ram_archetype_get) | **GET** /v1/component/ram/archetype | Ram All Archetype Name
*ComponentApi* | [**ram_archetype_config_v1_component_ram_archetype_config_get**](docs/ComponentApi.md#ram_archetype_config_v1_component_ram_archetype_config_get) | **GET** /v1/component/ram/archetype_config | Ram Archetype Config
*ComponentApi* | [**ram_impact_bottom_up_v1_component_ram_get**](docs/ComponentApi.md#ram_impact_bottom_up_v1_component_ram_get) | **GET** /v1/component/ram | Ram Impact Bottom Up
*ComponentApi* | [**ram_impact_bottom_up_v1_component_ram_post**](docs/ComponentApi.md#ram_impact_bottom_up_v1_component_ram_post) | **POST** /v1/component/ram | Ram Impact Bottom Up
*ComponentApi* | [**ssd_all_archetype_name_v1_component_ssd_archetype_get**](docs/ComponentApi.md#ssd_all_archetype_name_v1_component_ssd_archetype_get) | **GET** /v1/component/ssd/archetype | Ssd All Archetype Name
*ComponentApi* | [**ssd_archetype_config_v1_component_ssd_archetype_config_get**](docs/ComponentApi.md#ssd_archetype_config_v1_component_ssd_archetype_config_get) | **GET** /v1/component/ssd/archetype_config | Ssd Archetype Config
*ConsumptionProfileApi* | [**cpu_consumption_profile_v1_consumption_profile_cpu_post**](docs/ConsumptionProfileApi.md#cpu_consumption_profile_v1_consumption_profile_cpu_post) | **POST** /v1/consumption_profile/cpu | Cpu Consumption Profile
*DefaultApi* | [**welcome_page_get**](docs/DefaultApi.md#welcome_page_get) | **GET** / | Welcome Page
*IotApi* | [**get_archetype_config_v1_iot_iot_device_archetype_config_get**](docs/IotApi.md#get_archetype_config_v1_iot_iot_device_archetype_config_get) | **GET** /v1/iot/iot_device/archetype_config | Get Archetype Config
*IotApi* | [**iot_device_get_all_archetype_name_v1_iot_iot_device_archetypes_get**](docs/IotApi.md#iot_device_get_all_archetype_name_v1_iot_iot_device_archetypes_get) | **GET** /v1/iot/iot_device/archetypes | Iot Device Get All Archetype Name
*IotApi* | [**iot_device_impact_v1_iot_iot_device_get**](docs/IotApi.md#iot_device_impact_v1_iot_iot_device_get) | **GET** /v1/iot/iot_device | Iot Device Impact
*IotApi* | [**iot_device_impact_v1_iot_iot_device_post**](docs/IotApi.md#iot_device_impact_v1_iot_iot_device_post) | **POST** /v1/iot/iot_device | Iot Device Impact
*PeripheralApi* | [**external_hdd_get_all_archetype_name_v1_peripheral_external_hdd_archetypes_get**](docs/PeripheralApi.md#external_hdd_get_all_archetype_name_v1_peripheral_external_hdd_archetypes_get) | **GET** /v1/peripheral/external_hdd/archetypes | External Hdd Get All Archetype Name
*PeripheralApi* | [**external_hdd_get_archetype_config_v1_peripheral_external_hdd_archetype_config_get**](docs/PeripheralApi.md#external_hdd_get_archetype_config_v1_peripheral_external_hdd_archetype_config_get) | **GET** /v1/peripheral/external_hdd/archetype_config | External Hdd Get Archetype Config
*PeripheralApi* | [**external_hdd_impact_v1_peripheral_external_hdd_get**](docs/PeripheralApi.md#external_hdd_impact_v1_peripheral_external_hdd_get) | **GET** /v1/peripheral/external_hdd | External Hdd Impact
*PeripheralApi* | [**external_hdd_impact_v1_peripheral_external_hdd_post**](docs/PeripheralApi.md#external_hdd_impact_v1_peripheral_external_hdd_post) | **POST** /v1/peripheral/external_hdd | External Hdd Impact
*PeripheralApi* | [**external_ssd_get_all_archetype_name_v1_peripheral_external_ssd_archetypes_get**](docs/PeripheralApi.md#external_ssd_get_all_archetype_name_v1_peripheral_external_ssd_archetypes_get) | **GET** /v1/peripheral/external_ssd/archetypes | External Ssd Get All Archetype Name
*PeripheralApi* | [**external_ssd_get_archetype_config_v1_peripheral_external_ssd_archetype_config_get**](docs/PeripheralApi.md#external_ssd_get_archetype_config_v1_peripheral_external_ssd_archetype_config_get) | **GET** /v1/peripheral/external_ssd/archetype_config | External Ssd Get Archetype Config
*PeripheralApi* | [**external_ssd_impact_v1_peripheral_external_ssd_get**](docs/PeripheralApi.md#external_ssd_impact_v1_peripheral_external_ssd_get) | **GET** /v1/peripheral/external_ssd | External Ssd Impact
*PeripheralApi* | [**external_ssd_impact_v1_peripheral_external_ssd_post**](docs/PeripheralApi.md#external_ssd_impact_v1_peripheral_external_ssd_post) | **POST** /v1/peripheral/external_ssd | External Ssd Impact
*PeripheralApi* | [**monitor_get_all_archetype_name_v1_peripheral_monitor_archetypes_get**](docs/PeripheralApi.md#monitor_get_all_archetype_name_v1_peripheral_monitor_archetypes_get) | **GET** /v1/peripheral/monitor/archetypes | Monitor Get All Archetype Name
*PeripheralApi* | [**monitor_get_archetype_config_v1_peripheral_monitor_archetype_config_get**](docs/PeripheralApi.md#monitor_get_archetype_config_v1_peripheral_monitor_archetype_config_get) | **GET** /v1/peripheral/monitor/archetype_config | Monitor Get Archetype Config
*PeripheralApi* | [**monitor_impact_v1_peripheral_monitor_get**](docs/PeripheralApi.md#monitor_impact_v1_peripheral_monitor_get) | **GET** /v1/peripheral/monitor | Monitor Impact
*PeripheralApi* | [**monitor_impact_v1_peripheral_monitor_post**](docs/PeripheralApi.md#monitor_impact_v1_peripheral_monitor_post) | **POST** /v1/peripheral/monitor | Monitor Impact
*PeripheralApi* | [**peripheral_get_all_categories_v1_peripheral_all_get**](docs/PeripheralApi.md#peripheral_get_all_categories_v1_peripheral_all_get) | **GET** /v1/peripheral/all | Peripheral Get All Categories
*PeripheralApi* | [**usb_stick_get_all_archetype_name_v1_peripheral_usb_stick_archetypes_get**](docs/PeripheralApi.md#usb_stick_get_all_archetype_name_v1_peripheral_usb_stick_archetypes_get) | **GET** /v1/peripheral/usb_stick/archetypes | Usb Stick Get All Archetype Name
*PeripheralApi* | [**usb_stick_get_archetype_config_v1_peripheral_usb_stick_archetype_config_get**](docs/PeripheralApi.md#usb_stick_get_archetype_config_v1_peripheral_usb_stick_archetype_config_get) | **GET** /v1/peripheral/usb_stick/archetype_config | Usb Stick Get Archetype Config
*PeripheralApi* | [**usb_stick_impact_v1_peripheral_usb_stick_get**](docs/PeripheralApi.md#usb_stick_impact_v1_peripheral_usb_stick_get) | **GET** /v1/peripheral/usb_stick | Usb Stick Impact
*PeripheralApi* | [**usb_stick_impact_v1_peripheral_usb_stick_post**](docs/PeripheralApi.md#usb_stick_impact_v1_peripheral_usb_stick_post) | **POST** /v1/peripheral/usb_stick | Usb Stick Impact
*ServerApi* | [**get_archetype_config_v1_server_archetype_config_get**](docs/ServerApi.md#get_archetype_config_v1_server_archetype_config_get) | **GET** /v1/server/archetype_config | Get Archetype Config
*ServerApi* | [**server_get_all_archetype_name_v1_server_archetypes_get**](docs/ServerApi.md#server_get_all_archetype_name_v1_server_archetypes_get) | **GET** /v1/server/archetypes | Server Get All Archetype Name
*ServerApi* | [**server_impact_from_configuration_v1_server_post**](docs/ServerApi.md#server_impact_from_configuration_v1_server_post) | **POST** /v1/server/ | Server Impact From Configuration
*ServerApi* | [**server_impact_from_model_v1_server_get**](docs/ServerApi.md#server_impact_from_model_v1_server_get) | **GET** /v1/server/ | Server Impact From Model
*TerminalApi* | [**box_get_all_archetype_name_v1_terminal_box_archetypes_get**](docs/TerminalApi.md#box_get_all_archetype_name_v1_terminal_box_archetypes_get) | **GET** /v1/terminal/box/archetypes | Box Get All Archetype Name
*TerminalApi* | [**box_get_archetype_config_v1_terminal_box_archetype_config_get**](docs/TerminalApi.md#box_get_archetype_config_v1_terminal_box_archetype_config_get) | **GET** /v1/terminal/box/archetype_config | Box Get Archetype Config
*TerminalApi* | [**box_impact_v1_terminal_box_get**](docs/TerminalApi.md#box_impact_v1_terminal_box_get) | **GET** /v1/terminal/box | Box Impact
*TerminalApi* | [**box_impact_v1_terminal_box_post**](docs/TerminalApi.md#box_impact_v1_terminal_box_post) | **POST** /v1/terminal/box | Box Impact
*TerminalApi* | [**desktop_get_all_archetype_name_v1_terminal_desktop_archetypes_get**](docs/TerminalApi.md#desktop_get_all_archetype_name_v1_terminal_desktop_archetypes_get) | **GET** /v1/terminal/desktop/archetypes | Desktop Get All Archetype Name
*TerminalApi* | [**desktop_get_archetype_config_v1_terminal_desktop_archetype_config_get**](docs/TerminalApi.md#desktop_get_archetype_config_v1_terminal_desktop_archetype_config_get) | **GET** /v1/terminal/desktop/archetype_config | Desktop Get Archetype Config
*TerminalApi* | [**desktop_impact_v1_terminal_desktop_get**](docs/TerminalApi.md#desktop_impact_v1_terminal_desktop_get) | **GET** /v1/terminal/desktop | Desktop Impact
*TerminalApi* | [**desktop_impact_v1_terminal_desktop_post**](docs/TerminalApi.md#desktop_impact_v1_terminal_desktop_post) | **POST** /v1/terminal/desktop | Desktop Impact
*TerminalApi* | [**laptop_get_all_archetype_name_v1_terminal_laptop_archetypes_get**](docs/TerminalApi.md#laptop_get_all_archetype_name_v1_terminal_laptop_archetypes_get) | **GET** /v1/terminal/laptop/archetypes | Laptop Get All Archetype Name
*TerminalApi* | [**laptop_get_archetype_config_v1_terminal_laptop_archetype_config_get**](docs/TerminalApi.md#laptop_get_archetype_config_v1_terminal_laptop_archetype_config_get) | **GET** /v1/terminal/laptop/archetype_config | Laptop Get Archetype Config
*TerminalApi* | [**laptop_impact_v1_terminal_laptop_get**](docs/TerminalApi.md#laptop_impact_v1_terminal_laptop_get) | **GET** /v1/terminal/laptop | Laptop Impact
*TerminalApi* | [**laptop_impact_v1_terminal_laptop_post**](docs/TerminalApi.md#laptop_impact_v1_terminal_laptop_post) | **POST** /v1/terminal/laptop | Laptop Impact
*TerminalApi* | [**smartphone_get_all_archetype_name_v1_terminal_smartphone_archetypes_get**](docs/TerminalApi.md#smartphone_get_all_archetype_name_v1_terminal_smartphone_archetypes_get) | **GET** /v1/terminal/smartphone/archetypes | Smartphone Get All Archetype Name
*TerminalApi* | [**smartphone_get_archetype_config_v1_terminal_smartphone_archetype_config_get**](docs/TerminalApi.md#smartphone_get_archetype_config_v1_terminal_smartphone_archetype_config_get) | **GET** /v1/terminal/smartphone/archetype_config | Smartphone Get Archetype Config
*TerminalApi* | [**smartphone_impact_v1_terminal_smartphone_get**](docs/TerminalApi.md#smartphone_impact_v1_terminal_smartphone_get) | **GET** /v1/terminal/smartphone | Smartphone Impact
*TerminalApi* | [**smartphone_impact_v1_terminal_smartphone_post**](docs/TerminalApi.md#smartphone_impact_v1_terminal_smartphone_post) | **POST** /v1/terminal/smartphone | Smartphone Impact
*TerminalApi* | [**tablet_get_all_archetype_name_v1_terminal_tablet_archetypes_get**](docs/TerminalApi.md#tablet_get_all_archetype_name_v1_terminal_tablet_archetypes_get) | **GET** /v1/terminal/tablet/archetypes | Tablet Get All Archetype Name
*TerminalApi* | [**tablet_get_archetype_config_v1_terminal_tablet_archetype_config_get**](docs/TerminalApi.md#tablet_get_archetype_config_v1_terminal_tablet_archetype_config_get) | **GET** /v1/terminal/tablet/archetype_config | Tablet Get Archetype Config
*TerminalApi* | [**tablet_impact_v1_terminal_tablet_get**](docs/TerminalApi.md#tablet_impact_v1_terminal_tablet_get) | **GET** /v1/terminal/tablet | Tablet Impact
*TerminalApi* | [**tablet_impact_v1_terminal_tablet_post**](docs/TerminalApi.md#tablet_impact_v1_terminal_tablet_post) | **POST** /v1/terminal/tablet | Tablet Impact
*TerminalApi* | [**television_get_all_archetype_name_v1_terminal_television_archetypes_get**](docs/TerminalApi.md#television_get_all_archetype_name_v1_terminal_television_archetypes_get) | **GET** /v1/terminal/television/archetypes | Television Get All Archetype Name
*TerminalApi* | [**television_get_archetype_config_v1_terminal_television_archetype_config_get**](docs/TerminalApi.md#television_get_archetype_config_v1_terminal_television_archetype_config_get) | **GET** /v1/terminal/television/archetype_config | Television Get Archetype Config
*TerminalApi* | [**television_impact_v1_terminal_television_get**](docs/TerminalApi.md#television_impact_v1_terminal_television_get) | **GET** /v1/terminal/television | Television Impact
*TerminalApi* | [**television_impact_v1_terminal_television_post**](docs/TerminalApi.md#television_impact_v1_terminal_television_post) | **POST** /v1/terminal/television | Television Impact
*TerminalApi* | [**terminal_get_all_categories_v1_terminal_all_get**](docs/TerminalApi.md#terminal_get_all_categories_v1_terminal_all_get) | **GET** /v1/terminal/all | Terminal Get All Categories
*UtilsApi* | [**name_to_cpu_v1_utils_name_to_cpu_get**](docs/UtilsApi.md#name_to_cpu_v1_utils_name_to_cpu_get) | **GET** /v1/utils/name_to_cpu | Name To Cpu
*UtilsApi* | [**utils_get_all_case_type_v1_utils_case_type_get**](docs/UtilsApi.md#utils_get_all_case_type_v1_utils_case_type_get) | **GET** /v1/utils/case_type | Utils Get All Case Type
*UtilsApi* | [**utils_get_all_countries_v1_utils_country_code_get**](docs/UtilsApi.md#utils_get_all_countries_v1_utils_country_code_get) | **GET** /v1/utils/country_code | Utils Get All Countries
*UtilsApi* | [**utils_get_all_cpu_family_v1_utils_cpu_family_get**](docs/UtilsApi.md#utils_get_all_cpu_family_v1_utils_cpu_family_get) | **GET** /v1/utils/cpu_family | Utils Get All Cpu Family
*UtilsApi* | [**utils_get_all_cpu_model_range_v1_utils_cpu_model_range_get**](docs/UtilsApi.md#utils_get_all_cpu_model_range_v1_utils_cpu_model_range_get) | **GET** /v1/utils/cpu_model_range | Utils Get All Cpu Model Range
*UtilsApi* | [**utils_get_all_cpu_name_v1_utils_cpu_name_get**](docs/UtilsApi.md#utils_get_all_cpu_name_v1_utils_cpu_name_get) | **GET** /v1/utils/cpu_name | Utils Get All Cpu Name
*UtilsApi* | [**utils_get_all_impacts_criteria_v1_utils_impact_criteria_get**](docs/UtilsApi.md#utils_get_all_impacts_criteria_v1_utils_impact_criteria_get) | **GET** /v1/utils/impact_criteria | Utils Get All Impacts Criteria
*UtilsApi* | [**utils_get_all_ram_manufacturer_v1_utils_ram_manufacturer_get**](docs/UtilsApi.md#utils_get_all_ram_manufacturer_v1_utils_ram_manufacturer_get) | **GET** /v1/utils/ram_manufacturer | Utils Get All Ram Manufacturer
*UtilsApi* | [**utils_get_all_ssd_manufacturer_v1_utils_ssd_manufacturer_get**](docs/UtilsApi.md#utils_get_all_ssd_manufacturer_v1_utils_ssd_manufacturer_get) | **GET** /v1/utils/ssd_manufacturer | Utils Get All Ssd Manufacturer


## Documentation For Models

 - [Box](docs/Box.md)
 - [CPU](docs/CPU.md)
 - [Case](docs/Case.md)
 - [Cloud](docs/Cloud.md)
 - [ConfigurationServer](docs/ConfigurationServer.md)
 - [ConsumptionProfileCPU](docs/ConsumptionProfileCPU.md)
 - [Desktop](docs/Desktop.md)
 - [Disk](docs/Disk.md)
 - [ElecFactors](docs/ElecFactors.md)
 - [ExternalHDD](docs/ExternalHDD.md)
 - [ExternalSSD](docs/ExternalSSD.md)
 - [FunctionalBlock](docs/FunctionalBlock.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [IoT](docs/IoT.md)
 - [Laptop](docs/Laptop.md)
 - [LocationInner](docs/LocationInner.md)
 - [ModelServer](docs/ModelServer.md)
 - [Monitor](docs/Monitor.md)
 - [Motherboard](docs/Motherboard.md)
 - [PowerSupply](docs/PowerSupply.md)
 - [RAM](docs/RAM.md)
 - [Server](docs/Server.md)
 - [Smartphone](docs/Smartphone.md)
 - [Tablet](docs/Tablet.md)
 - [Television](docs/Television.md)
 - [TimeWorkload](docs/TimeWorkload.md)
 - [Usage](docs/Usage.md)
 - [UsageCloud](docs/UsageCloud.md)
 - [UsageServer](docs/UsageServer.md)
 - [UsbStick](docs/UsbStick.md)
 - [ValidationError](docs/ValidationError.md)
 - [WorkloadPower](docs/WorkloadPower.md)
 - [WorkloadTime](docs/WorkloadTime.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




